==> beastiary-0.7.0.tar.gz: beastiary-0.7.0/beastiary/api/endpoints/traces.py <==
from beastiary.schemas import sample
from typing import Any, List
from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session

from beastiary import crud, schemas
from beastiary.api import deps

router = APIRouter()


@router.get("/", response_model=List[schemas.Trace])
def get_traces(
    db: Session = Depends(deps.get_db),
    skip: int = 0,
    limit: int = 100,
) -> Any:
    """
    Retrieve traces.
    """
    traces = crud.trace.get_multi(db=db, skip=skip, limit=limit)
    return traces


@router.get("/{trace_id}", response_model=schemas.Trace)
def get_trace(trace_id, db: Session = Depends(deps.get_db)) -> Any:
    """
    Retrieve traces.
    """
    trace = crud.trace.get(db=db, id=trace_id)
    if not trace:
        raise HTTPException(404, "Trace not found!")
    return trace


def get_headers(path):
    with open(path, "r") as f:
        headers_set = False
        while True:
            line = f.readline()
            if line.startswith("#"):
                continue
            return f.tell(), line


@router.post("/", response_model=schemas.Trace)
def create_trace(
    *,
    db: Session = Depends(deps.get_db),
    trace_in: schemas.TraceCreate,
) -> Any:
    """
    Create new trace.
    """
    # get headers
    try:
        last_byte, headers = get_headers(trace_in.path)
    except FileNotFoundError as e:
        raise HTTPException(404, detail="Could not find log file!")
    headers = headers.split()
    headers[0] = "state"
    headers_line = " ".join(headers)
    trace = crud.trace.create(
        db=db, obj_in=trace_in, headers_line=headers_line, last_byte=last_byte
    )
    return trace

==> beastiary-1.2.3.tar.gz: beastiary-1.2.3/beastiary/api/endpoints/traces.py <==
from beastiary.api.core import add_trace
from beastiary.models.trace import Trace
from beastiary.schemas import sample
from typing import Any, List
from fastapi import APIRouter, Depends, HTTPException
from sqlalchemy.orm import Session

from beastiary import crud, schemas
from beastiary.api import deps
from beastiary.api.core import check_for_new_samples

router = APIRouter()


@router.get("/", response_model=List[schemas.Trace])
def get_traces(
    db: Session = Depends(deps.get_db),
    skip: int = 0,
    limit: int = 100,
) -> List[Trace]:
    """
    Retrieve traces.
    """
    traces = crud.trace.get_multi(db=db, skip=skip, limit=limit)
    return traces


@router.get("/{trace_id}", response_model=schemas.Trace)
def get_trace(trace_id: int, db: Session = Depends(deps.get_db)) -> Trace:
    """
    Retrieve traces.
    """
    trace = crud.trace.get(db=db, id=trace_id)
    if not trace:
        raise HTTPException(404, "Trace not found!")
    return trace


@router.post("/", response_model=schemas.Trace)
def create_trace(
    *,
    db: Session = Depends(deps.get_db),
    trace_in: schemas.TraceCreate,
) -> Trace:
    """
    Create new trace.
    """
    try:
        trace = add_trace(db, trace_in)
    except FileNotFoundError as e:
        raise HTTPException(404, detail="Could not find log file!")
    except Exception as e:
        raise HTTPException(500, detail=f"Could not add {trace_in.path}")
    # get samples
    # check_for_new_samples(db, trace=trace)
    return trace
